@@ -142,7 +142,7 @@ def startOps(ops):
     sim_dates.append(getCurrTime(ops))
     mem=ops['mem']
     for asset in assets:
-        dbar=b3.getBars(asset,mem)
+        dbar=b3.getBars(asset,mem,b3.INTRADAY)
         if not dbar is None and not dbar.empty:
             dbars[asset]=dbar
         else:
@@ -208,7 +208,7 @@ def getCurrBars(ops,dbars):
     for asset in assets:
         dbar=dbars[asset]
         #pega nova barra    
-        aux=b3.getBars(asset,1) # pega uma barra!
+        aux=b3.getBars(asset,1,b3.INTRADAY) # pega uma barra!
         if not aux is None and not aux.empty:
             dbar=dbar.iloc[1:,] #remove barra mais antiga
             #adiciona nova barra
