@@ -3,7 +3,6 @@
 # Author: Paulo Al Castro
 # Date: 2020-11-17
 
-
 import pandas as pd 
 import numpy as np 
 import mt5b3.mt5b3 as b3
@@ -20,7 +19,7 @@ def rsi(returns):
             u=u+r
             uc=uc+1
         else:
-            d=d+r
+            d=d+abs(r)
             dc=dc+1
     if uc>0:
         u=u/uc
